local BaikCore = LibStub("AceAddon-3.0"):GetAddon("BaikCore")
local BaikUnitFrame = BaikCore.BaikUnitFrame
local LayoutAttrib = BaikCore.LayoutAttrib
local Log = BaikCore.Log

-- Add Module
local PlayerFrameMod = BaikUnitFrame:NewModule("PlayerFrameMod", "AceHook-3.0")

-- UI Layout that gets moved by Blizzard
local DYNAMIC_TABLE = {
    [PlayerName] = LayoutAttrib:Create(100, 12, "CENTER", 50, 36),
    [PlayerFrameHealthBar] = LayoutAttrib:Create(119, 19, "TOPLEFT", 106, -22),
    [PlayerFrameManaBar] = LayoutAttrib:Create(119, 12, "TOPLEFT", 106, -41),
}

-- UI Layout that doesn't get moved
local STATIC_TABLE = {
    [PlayerFrameHealthBarText] = LayoutAttrib:Create(nil, nil, "CENTER", 50, 18),
    [PlayerFrameHealthBarTextLeft] = LayoutAttrib:Create(nil, nil, "LEFT", 110, 18),
    [PlayerFrameHealthBarTextRight] = LayoutAttrib:Create(nil, nil, "RIGHT", -8, 18),
    [PlayerFrameManaBarText] = LayoutAttrib:Create(nil, nil, "CENTER", 50, 3),
    [PlayerFrameManaBarTextLeft] = LayoutAttrib:Create(nil, nil, "LEFT", 110, 3),
    [PlayerFrameManaBarTextRight] = LayoutAttrib:Create(nil, nil, "RIGHT", -8, 3),
}

-- Private Methods
local function LoadDynamic()
    Log:i("Syncing unitframe dynamic frames")
    for frame, layout in pairs(DYNAMIC_TABLE) do
        layout:SyncRegion(frame, true)
    end
end

local function LoadStatic()
    Log:i("Syncing unitframe static frames")
    for frame, layout in pairs(STATIC_TABLE) do
        layout:SyncRegion(frame, true)
    end
end

-- PostHook Methods
local function PostHook_PlayerFrame_ToPlayerArt(...)
    LoadDynamic()
end

-- Ace3 Callbacks
function PlayerFrameMod:OnInitialize()
    Log:v("PlayerFrameMod_OnInitialize")
end

function PlayerFrameMod:OnEnable()
    Log:v("PlayerFrameMod_OnEnable")
    LoadDynamic()
    LoadStatic()
    self:SecureHook("PlayerFrame_ToPlayerArt", PostHook_PlayerFrame_ToPlayerArt)
end

function PlayerFrameMod:OnDisable()
    Log:v("PlayerFrameMod_OnDisable")
    self:UnhookAll()
end
